@@ -1,16 +1,16 @@
 /* biji-zeitgeist.c
  * Copyright (C) Pierre-Yves LUYTEN 2011 <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.*/
 
@@ -34,9 +34,9 @@ biji_zeitgeist_init (void)
 
   log = zeitgeist_log_new ();
   event = zeitgeist_event_new_full (
-    NULL, NULL, "application://bijiben.desktop", NULL, NULL);
+    NULL, NULL, "application://org.gnome.bijiben.desktop", NULL, NULL);
 
-  ptr_arr = g_ptr_array_new ();
+  ptr_arr = g_ptr_array_new_with_free_func (g_object_unref);
   g_ptr_array_add (ptr_arr, event);
 
   ds = zeitgeist_data_source_new_full ("org.gnome.bijiben,dataprovider",
@@ -47,7 +47,8 @@ biji_zeitgeist_init (void)
   zg_dsr = zeitgeist_data_source_registry_new ();
   zeitgeist_data_source_registry_register_data_source (zg_dsr, ds,
                                                        NULL, NULL, NULL);
-  g_ptr_array_set_free_func (ptr_arr, g_object_unref);
+  g_object_unref (ds);
+  g_object_unref (zg_dsr);
   g_ptr_array_unref (ptr_arr);
 
   return log;
@@ -88,20 +89,20 @@ check_insert_create_zeitgeist (BijiNoteObj *note)
   GPtrArray          *templates;
   ZeitgeistEvent     *event;
   ZeitgeistSubject   *subject;
-  
+
   uri = g_strdup_printf ("file://%s", biji_item_get_uuid (BIJI_ITEM (note)));
   log = biji_manager_get_zg_log (biji_item_get_manager (BIJI_ITEM (note)));
-  
-  templates = g_ptr_array_new ();
-  event = zeitgeist_event_new_full (ZEITGEIST_ZG_CREATE_EVENT, 
+
+  templates = g_ptr_array_new_with_free_func (g_object_unref);
+  event = zeitgeist_event_new_full (ZEITGEIST_ZG_CREATE_EVENT,
                                     NULL,
-                                    "application://bijiben.desktop",
+                                    "application://org.gnome.bijiben.desktop",
                                     NULL, NULL);
   subject = zeitgeist_subject_new ();
   zeitgeist_subject_set_uri (subject, uri);
   zeitgeist_event_add_subject (event, subject);
   g_ptr_array_add (templates, event);
-  
+
   zeitgeist_log_find_events (log,
                              zeitgeist_time_range_new_to_now (),
                              templates,
@@ -111,12 +112,15 @@ check_insert_create_zeitgeist (BijiNoteObj *note)
                              NULL,
                              (GAsyncReadyCallback) on_find_create_event,
                              note);
+
+  g_ptr_array_unref (templates);
+  g_free (uri);
 }
 
 
 void
 insert_zeitgeist (BijiNoteObj *note,
-                  gchar *zg_interpretation)
+                  const gchar *zg_interpretation)
 {
   gchar *uri;
   const gchar *title;
@@ -149,7 +153,7 @@ insert_zeitgeist (BijiNoteObj *note,
 
   event = zeitgeist_event_new_full (zg_interpretation,
                                     ZEITGEIST_ZG_USER_ACTIVITY,
-                                    "application://bijiben.desktop",
+                                    "application://org.gnome.bijiben.desktop",
                                     "",
                                     subject,
                                     NULL);
@@ -161,9 +165,11 @@ insert_zeitgeist (BijiNoteObj *note,
 
   zeitgeist_log_insert_event_no_reply (log, event, NULL);
   g_free (uri);
+  g_object_unref (event);
+  g_object_unref (subject);
 
 
-  /* 
+  /*
    * Check if the note
    * was already created into zeitgeist
    */
